@@ -1,36 +1,54 @@
-from .connection import Connection
-from .collection import Collection
-from .cursor import Cursor, ASCENDING, DESCENDING
-from .results import (
-    InsertOneResult,
-    InsertManyResult,
-    UpdateResult,
-    DeleteResult,
-    BulkWriteResult,
-)
-from .requests import InsertOne, UpdateOne, DeleteOne
-from .exceptions import MalformedQueryException, MalformedDocument
-from .changestream import ChangeStream
-from .raw_batch_cursor import RawBatchCursor
+from .binary import Binary
 from .bulk_operations import BulkOperationExecutor
+from .changestream import ChangeStream
+from .collection import Collection
+from .connection import Connection
+from .exceptions import MalformedQueryException, MalformedDocument
+from .requests import InsertOne, UpdateOne, DeleteOne
+from .results import (
+    BulkWriteResult,
+    DeleteResult,
+    InsertManyResult,
+    InsertOneResult,
+    UpdateResult,
+)
+
+# Import cursor classes from collection module
+from .collection.aggregation_cursor import AggregationCursor
+from .collection.cursor import Cursor, ASCENDING, DESCENDING
+from .collection.raw_batch_cursor import RawBatchCursor
+
+# GridFS support
+try:
+    from .gridfs import GridFSBucket, GridFS
+
+    _HAS_GRIDFS = True
+except ImportError:
+    _HAS_GRIDFS = False
 
 __all__ = [
-    "Connection",
-    "Collection",
-    "Cursor",
     "ASCENDING",
-    "DESCENDING",
-    "InsertOneResult",
-    "InsertManyResult",
-    "UpdateResult",
-    "DeleteResult",
-    "BulkWriteResult",
-    "InsertOne",
-    "UpdateOne",
-    "DeleteOne",
-    "MalformedQueryException",
-    "MalformedDocument",
-    "ChangeStream",
-    "RawBatchCursor",
+    "AggregationCursor",
+    "Binary",
     "BulkOperationExecutor",
+    "BulkWriteResult",
+    "ChangeStream",
+    "Collection",
+    "Connection",
+    "Cursor",
+    "DESCENDING",
+    "DeleteOne",
+    "DeleteResult",
+    "InsertManyResult",
+    "InsertOne",
+    "InsertOneResult",
+    "MalformedDocument",
+    "MalformedQueryException",
+    "RawBatchCursor",
+    "UpdateOne",
+    "UpdateResult",
 ]
+
+# Add GridFS to __all__ if available
+if _HAS_GRIDFS:
+    __all__.extend(["GridFSBucket", "GridFS"])
